# trilium-py
Python client for ETAPI of Trilium Note.

# Develop

```
python -m pip install --user -e .
```

# Original OpenAPI Documentation
The original OpenAPI document is [here](https://github.com/zadam/trilium/blob/master/src/etapi/etapi.openapi.yaml).
You can open it with [swagger editor](https://editor.swagger.io/).